@@ -5,7 +5,7 @@ BEGIN {
   use Exporter;
   use vars qw($VERSION @ISA @EXPORT);
 
-  $VERSION = '0.012';
+  $VERSION = '0.020';
   @ISA     = qw(Exporter);
   @EXPORT  = qw(
     get_colorscheme
@@ -708,6 +708,517 @@ my $colorschemes = {
     7  => "CCCCC6",
     15 => "F8F8F2",
   },
+
+ astromouse => {
+   0 => "1c1c1c",
+   1 => "d770af",
+   10 => "8fb676",
+   11 => "c8bc45",
+   12 => "8fa7b9",
+   13 => "bd89de",
+   14 => "6ec2a8",
+   15 => "dad3d3",
+   3 => "d0d26b",
+   5 => "a488d9",
+   6 => "7fcab3",
+   7 => "8d8d8d",
+   8 => "3d3a3a",
+   9 => "d28abf",
+ },
+
+  belge => {
+    0 => 252525,
+    1 => "EF6769",
+    10 => "B6E354",
+    11 => "FD971F",
+    12 => "87CEEB",
+    13 => 996600,
+    14 => "87CEEB",
+    15 => "FDFDFD",
+    2 => "A6E22E",
+    3 => "FD971F",
+    4 => "6495ED",
+    5 => "DEB887",
+    6 => "B0C4DE",
+    7 => "DBDCDC",
+    8 => 454545,
+    9 => "FC7CA5"
+  },
+
+  "bitmute" => {
+    0 => 282828,
+    1 => "b76969",
+    10 => "839d84",
+    11 => 919864,
+    12 => "73718f",
+    13 => 987397,
+    14 => "758c93",
+    15 => "aeaeae",
+    2 => "719d72",
+    3 => 909858,
+    4 => "68668f",
+    5 => 966894,
+    6 => 688891,
+    7 => "8e8e8e",
+    8 => 494949,
+    9 => "b87e7e"
+  },
+
+  "bleh-1" => {
+    0 => 666666,
+    1 => 996578,
+    10 => "95b548",
+    11 => "bd814b",
+    12 => "4c83bf",
+    13 => "a04bbd",
+    14 => "4dbda8",
+    15 => 848484,
+    2 => 889965,
+    3 => 998565,
+    4 => "657a99",
+    5 => "8b6599",
+    6 => "65998d",
+    7 => "a5a5a4",
+    8 => "8c847f",
+    9 => "bd4b76"
+  },
+
+  "cloud" => {
+    0 => 222827,
+    1 => "D5A8E3",
+    10 => "63B0B0",
+    11 => "C0C0DD",
+    12 => "5786BC",
+    13 => "3F3442",
+    14 => "849DA2",
+    15 => "D9D6CF",
+    2 => "9C75DD",
+    3 => "9898AE",
+    4 => "654A96",
+    5 => 625566,
+    6 => "A9D1DF",
+    7 => "E6EBE5",
+    8 => "5D6F74",
+    9 => "CD749C"
+  },
+
+  "colorfulcolors" => {
+    0 => 151515,
+    1 => "FF8EAF",
+    10 => "A6E179",
+    11 => "FFDF6B",
+    12 => "79D2FF",
+    13 => "BB5D79",
+    14 => "87A8AF",
+    15 => "E2F1F6",
+    2 => "A6E25F",
+    3 => "F8E578",
+    4 => "A6E2F0",
+    5 => "E85B92",
+    6 => "5F868F",
+    7 => "D5F1F2",
+    8 => 696969,
+    9 => "ED4C7A"
+  },
+
+  "deafened" => {
+    0 => "3d3e3d",
+    1 => "755a5b",
+    10 => "87a376",
+    11 => "a39b76",
+    12 => "758ba3",
+    13 => "9f76a3",
+    14 => "899ca1",
+    15 => "f8f8f2",
+    2 => "68755a",
+    3 => "756e5a",
+    4 => "5b6976",
+    5 => "755b76",
+    6 => 465457,
+    7 => "ccccc6",
+    8 => "5a5b5c",
+    9 => "a37679"
+  },
+
+  "dotshare" => {
+    0 => 101010,
+    1 => "E84F4F",
+    10 => "A0CF5D",
+    11 => "F39D21",
+    12 => "4E9FB1",
+    13 => "8542FF",
+    14 => "42717B",
+    15 => "dddddd",
+    2 => "B8D68C",
+    3 => "E1AA5D",
+    4 => "7DC1CF",
+    5 => "9B64FB",
+    6 => "6D878D",
+    7 => "dddddd",
+    8 => 404040,
+    9 => "D23D3D"
+  },
+
+  "epiphany" => {
+    0 => 565656,
+    1 => "AC4F4F",
+    10 => "8CCD6C",
+    11 => "C5D67D",
+    12 => 647396,
+    13 => "CDB4C9",
+    14 => "505B6C",
+    15 => "C0C0C0",
+    2 => "88AB77",
+    3 => "D0D9AD",
+    4 => 677088,
+    5 => "CDCDB4",
+    6 => 445362,
+    7 => "FFFFFF",
+    8 => 656565,
+    9 => "E85555"
+  },
+
+  "erebus" => {
+    0 => 757575,
+    1 => "FF5F5F",
+    10 => "FF9F6F",
+    11 => "FF5F5F",
+    12 => "DEA3E5",
+    13 => "D7AFAF",
+    14 => "AF5FD7",
+    15 => 757575,
+    2 => "DE8A36",
+    3 => "D78787",
+    4 => "AF5FD7",
+    5 => "FF87D7",
+    6 => "DEA3E5",
+    7 => "B8B8B8",
+    8 => "B8B8B8",
+    9 => "D78787"
+  },
+
+  "fishbone" => {
+    0 => "293b3b",
+    1 => "bf5357",
+    10 => "51a55f",
+    11 => "aea75d",
+    12 => "5177a5",
+    13 => "bf6e63",
+    14 => "7859a5",
+    15 => "876f6f",
+    2 => "41a551",
+    3 => "aea64f",
+    4 => "416ea5",
+    5 => "bf6053 ",
+    6 => "714da5",
+    7 => 876868,
+    8 => 344040,
+    9 => "bf6367"
+  },
+
+  "hybrid" => {
+    0 => 393939,
+    1 => "da4939",
+    10 => "8fb676",
+    11 => "c8bc45",
+    12 => "d0d0ff",
+    13 => "a761c2",
+    14 => "6e98a4",
+    15 => "c2c2c2",
+    3 => "d0d26b",
+    4 => "6d9cbe",
+    5 => "9f5079",
+    6 => "435d75",
+    7 => "c2c2c2",
+    8 => 474747,
+    9 => "ff6c5c"
+  },
+
+  "iiamblack" => {
+    0 => 393939,
+    1 => "da4939",
+    10 => "a5c261",
+    11 => "bc9458",
+    12 => "d0d0ff",
+    13 => "a761c2",
+    14 => "6e98a4",
+    15 => "dddddd",
+    2 => "519f50",
+    3 => "cc7833",
+    4 => "6d9cbe",
+    5 => "9f5079",
+    6 => "435d75",
+    7 => "dddddd",
+    8 => 474747,
+    9 => "ff6c5c"
+  },
+
+  "insignificato" => {
+    0 => "3d3e3d",
+    1 => "755a5b",
+    10 => "87a376",
+    11 => "a39b76",
+    12 => "758ba3",
+    13 => "9f76a3",
+    14 => "75a3a1",
+    15 => "aeafb0",
+    2 => "68755a",
+    3 => "756e5a",
+    4 => "5b6976",
+    5 => "755b76",
+    6 => "5b7674",
+    7 => 808080,
+    8 => "5a5b5c",
+    9 => "a37679"
+  },
+
+  "jwr_dark" => {
+    0 => 333333,
+    1 => "8C4665",
+    10 => "53A6A6",
+    11 => "A270A3",
+    12 => "477AB3",
+    13 => "7E62B3",
+    14 => "6096BF",
+    15 => "C0C0C0",
+    2 => 287373,
+    3 => "7E5D7A",
+    4 => 395573,
+    5 => "5E468C",
+    6 => "31658C",
+    7 => "899CA1",
+    8 => "3D3D3D",
+    9 => "BF4D80"
+  },
+
+  "mikado" => {
+    0 => "322a2c",
+    1 => "a04363",
+    10 => "b4aa30",
+    11 => "c7a551",
+    12 => "74999e",
+    13 => "9c818e",
+    14 => "9fa590",
+    15 => "c1c4bc",
+    2 => "9b9329",
+    3 => "bf7a29",
+    4 => "6a8c8c",
+    5 => 856774,
+    6 => 757978,
+    7 => "bcbcaf",
+    8 => "46423b",
+    9 => "ae837a"
+  },
+
+  "mikazuki" => {
+    0 => "2a1d17",
+    1 => "da1657",
+    10 => "6cb87a",
+    11 => "e3da84",
+    12 => "8ca8a3",
+    13 => "ffa64f",
+    14 => "a167c7",
+    15 => "fdfdfd",
+    2 => "3ea250",
+    3 => "e3d33d",
+    4 => "3ea290",
+    5 => "ff850d",
+    6 => "8c16da",
+    7 => "e9e9e9",
+    8 => "4f362b",
+    9 => "da4375"
+  },
+
+  "nucolors" => {
+    0 => 393939,
+    1 => "FF9F95",
+    10 => "DBFFB3",
+    11 => "FFBE64",
+    12 => "7EB6FF",
+    13 => "E296FF",
+    14 => "9CE9FF",
+    15 => "dddddd",
+    2 => "E2FFC7",
+    3 => "FFFFB9",
+    4 => "A8CEEA",
+    5 => "E2B5CC",
+    6 => "C2EFFF",
+    7 => "dddddd",
+    8 => 474747,
+    9 => "FF8D80"
+  },
+
+  "nudge" => {
+    0 => 658280,
+    1 => "822f5d",
+    10 => "28634d",
+    11 => "9d5823",
+    12 => "415c77",
+    13 => 532706,
+    14 => "3a6868",
+    15 => 330801,
+    2 => "184a31",
+    3 => "9d4500",
+    4 => 304465,
+    5 => 330801,
+    6 => 175552,
+    7 => 110005,
+    8 => "8ca8a6",
+    9 => "a24b76"
+  },
+
+  "orangish" => {
+    0 => "251f1f",
+    1 => "eb4509",
+    10 => "95e76b",
+    11 => "ffac18",
+    12 => "46aede",
+    13 => "e32c57",
+    14 => "d6dbac",
+    15 => "efefef",
+    2 => "94e76b",
+    3 => "ffac18",
+    4 => "46aede",
+    5 => "e32c57",
+    6 => "d6dbac",
+    7 => "efefef",
+    8 => "5e5e5e",
+    9 => "eb4509"
+  },
+
+  "parker_brothers" => {
+    0 => "322a2c",
+    1 => "79220E",
+    10 => "76550F",
+    11 => "B57F02",
+    12 => 908862,
+    13 => "624A35",
+    14 => "393E38",
+    15 => "A59058",
+    2 => "344B1B",
+    3 => "B45B00",
+    4 => 434045,
+    5 => "5C1E25",
+    6 => 394745,
+    7 => "AE8842",
+    8 => "46423b",
+    9 => "AA261F"
+  },
+
+  "pulp" => {
+    0 => "86817e",
+    1 => "d75756",
+    10 => "688c7d",
+    11 => "ffb365",
+    12 => "68778c",
+    13 => "8c686a",
+    14 => "86abd9",
+    15 => "f7f8f2",
+    2 => "688c7d",
+    3 => "ffb365",
+    4 => "68778c",
+    5 => "fdb3b2",
+    6 => "86abd9",
+    7 => "f7f8f2",
+    8 => "86817e",
+    9 => "a63a3a"
+  },
+
+  "sexcolors" => {
+    0 => 252525,
+    1 => "FF9F95",
+    10 => "B6E354",
+    11 => "FD971F",
+    12 => "587aa4",
+    13 => "46a4ff",
+    14 => "A3BABF",
+    15 => "FDFDFD",
+    2 => "A6E22E",
+    3 => "FD971F",
+    4 => "435e87",
+    5 => "789ec6",
+    6 => "5E7175",
+    7 => "DBDCDC",
+    8 => 454545,
+    9 => "FF8D80"
+  },
+
+  "shic" => {
+    0 => 494949,
+    1 => "B9716E",
+    10 => "326F58",
+    11 => "C7C575",
+    12 => "507F7C",
+    13 => "A387A6",
+    14 => "927C4B",
+    15 => "C7C7C7",
+    2 => "588F7A",
+    3 => "AAA857",
+    4 => "A0C3C0",
+    5 => "735E74",
+    6 => 695935,
+    7 => "B1B1B1",
+    8 => 484848,
+    9 => "8F5A58"
+  },
+
+  "splurge" => {
+    0 => "4a4b4a",
+    1 => "D7699A",
+    10 => "A3F2A0",
+    11 => "F5CDA2",
+    12 => "A2C1F5",
+    13 => "D2A2F5",
+    14 => "A0E9F2",
+    15 => "FDFDFD",
+    2 => "80D468",
+    3 => "D7A169",
+    4 => "6985D7",
+    5 => "C86AD4",
+    6 => "6FCCD1",
+    7 => "DBDCDC",
+    8 => 696969,
+    9 => "F5A2B5"
+  },
+
+  "swayr" => {
+    0 => "1c1709",
+    1 => "8e4317",
+    10 => "d9d138",
+    11 => "ffab26",
+    12 => "8aa9ed",
+    13 => "ff8cb8",
+    14 => "43bfe0",
+    15 => "f2e8c9",
+    2 => 787200,
+    3 => "945c00",
+    4 => 315094,
+    5 => "5c2e40",
+    6 => "00617d",
+    7 => "c2b9a1",
+    8 => "4f4939",
+    9 => "f07935"
+  },
+
+  "visibone" => {
+    0 => 666666,
+    1 => "CC6666",
+    10 => "99FFCC",
+    11 => "FFCC99",
+    12 => "99CCFF",
+    13 => "FF99CC",
+    14 => "99FFFF",
+    15 => "FFFFFF",
+    2 => "66CC99",
+    3 => "CC9966",
+    4 => "6699CC",
+    5 => "CC6699",
+    6 => "66CCCC",
+    7 => "CCCCCC",
+    8 => 999999,
+    9 => "FF9999"
+  },
+
 };
 
 sub get_colorschemes { return keys %{ $colorschemes }; }
